==> nextcloud-20.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/el.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Πίνακας ελέγχου",
    "Dashboard app" : "Εφαρμογή Πίνακα Ελέγχου",
    "Show something" : "Δείξε οτιδήποτε",
    "Customize" : "Προσαρμογή",
    "Edit widgets" : "Επεξεργασία μικροεφαρμογών",
    "Get more widgets from the app store" : "Λάβετε περισσότερες μικροεφαρμογές από το App Store",
    "Change background image" : "Αλλαγή φωτογραφίας παρασκηνίου",
    "Weather service" : "Υπηρεσία καιρού",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Για το απόρρητό σας, τα δεδομένα καιρού ζητούνται από τον διακομιστή Nextcloud για λογαριασμό σας, ώστε η υπηρεσία καιρού να μην λαμβάνει προσωπικά στοιχεία.",
    "Weather data from Met.no" : "Δεδομένα καιρού από το Met.no",
    "geocoding with Nominatim" : "geocoding με Nominatim",
    "elevation data from OpenTopoData" : "δεδομένα elevation από OpenTopoData",
    "Weather" : "Καιρός",
    "Status" : "Κατάσταση",
    "Good evening, {name}" : "Καλό βράδυ, {name}",
    "Good evening" : "Καλό βράδυ",
    "Good afternoon, {name}" : "Καλό απόγευμα, {name}",
    "Good afternoon" : "Καλό απόγευμα",
    "Good morning, {name}" : "Καλημέρα, {name}",
    "Good morning" : "Καλημέρα",
    "Good night, {name}" : "Καληνύχτα, {name}",
    "Good night" : "Καληνύχτα",
    "Pick from files" : "Επιλογή από τα αρχεία",
    "Default images" : "Προεπιλεγμένες εικόνες",
    "Plain background" : "Απλό παρασκήνιο",
    "Insert from {productName}" : "Εισαγωγή από {productName}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/el.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Πίνακας ελέγχου",
    "Dashboard app" : "Εφαρμογή Πίνακα Ελέγχου",
    "Show something" : "Δείξε οτιδήποτε",
    "Customize" : "Προσαρμογή",
    "Edit widgets" : "Επεξεργασία μικροεφαρμογών",
    "Get more widgets from the app store" : "Λάβετε περισσότερες μικροεφαρμογές από το App Store",
    "Change background image" : "Αλλαγή φωτογραφίας παρασκηνίου",
    "Weather service" : "Υπηρεσία καιρού",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Για το απόρρητό σας, τα δεδομένα καιρού ζητούνται από τον διακομιστή Nextcloud για λογαριασμό σας, ώστε η υπηρεσία καιρού να μην λαμβάνει προσωπικά στοιχεία.",
    "Weather data from Met.no" : "Δεδομένα καιρού από το Met.no",
    "geocoding with Nominatim" : "geocoding με Nominatim",
    "elevation data from OpenTopoData" : "δεδομένα elevation από OpenTopoData",
    "Weather" : "Καιρός",
    "Status" : "Κατάσταση",
    "Good morning" : "Καλημέρα",
    "Good morning, {name}" : "Καλημέρα, {name}",
    "Good afternoon" : "Καλό απόγευμα",
    "Good afternoon, {name}" : "Καλό απόγευμα, {name}",
    "Good evening" : "Καλό βράδυ",
    "Good evening, {name}" : "Καλό βράδυ, {name}",
    "Hello" : "Γειά",
    "Hello, {name}" : "Γειά, {όνομα}",
    "Pick from Files" : "Επιλέξτε από αρχεία",
    "Default images" : "Προεπιλεγμένες εικόνες",
    "Plain background" : "Απλό παρασκήνιο",
    "Insert from {productName}" : "Εισαγωγή από {productName}",
    "Good night, {name}" : "Καληνύχτα, {name}",
    "Good night" : "Καληνύχτα",
    "Pick from files" : "Επιλογή από τα αρχεία"
},
"nplurals=2; plural=(n != 1);");
